@@ -9,6 +9,13 @@ NULL
 #' @keywords internal
 NULL
 
+#' @export
+#' @rdname arkhe-deprecated
+needs <- function(...) {
+  # .Deprecated("assert_package()", old = "needs()")
+  assert_package(...)
+}
+
 #' @export
 #' @rdname arkhe-deprecated
 assert_dimensions <- function(...) {
